Module all_star

Module all_star 

Unimplemented as you can only get data as the ASG is ongoing.

…or it’s privatized by a key, regardless, this allows easy automation of the ASG ballot and I do not want to cause an incident where people send 10k ballots by automating the request.

Modules

ballot
final_vote
write_ins