Module attendance

Module attendance 

Attendance for games and seasons.

Typically only seasonal AttendanceRecords are accessible so some extra work is needed to get a specific game’s attendance.

Within regards to attendance, the term frequently used is “Opening” over “Game”; this is for reasons including but not limited to: single ticket double headers, and rescheduled games.

Averages are calculated with respect to the # of openings on the sample, not the number of games the team played as either “home” or “away”.

Since the 2020 season had 0 total attendance, the ‘peak attendance game’ has its default value of NaiveDate::MIN

Structs

AttendanceRecord
A record of attendance.
AttendanceRequest
Returns AttendanceResponse
AttendanceRequestBuilder
Use builder syntax to set the inputs and finish with build().
AttendanceResponse
Response from the attendance endpoint. Returns a Vec of AttendanceRecord.
DatedAttendance
An attendance record of a single game.
SeasonWithMinorId
Season with an optional minor part