pub struct SeasonWithMinorId { /* private fields */ }Expand description
Season with an optional minor part
Some seasons are duplicated since there might be multiple in the same year, because of that we get stuff like 2018.2.