Module awards

Module awards 

An award, such as the Cy Young, MVP, etc.

There are over a thousand awards for pretty much every organized league you can think of.

Structs

Award
An award, such as the Cy Young or MVP.
AwardId
A string representing an award, ID of award, used in AwardRequest
AwardRequest
Returns [AwardResponse]
AwardRequestBuilder
Use builder syntax to set the inputs and finish with build().
AwardsResponse
Response from the awards endpoint. Returns a Vec of Awards