Module conference

Module conference 

A conference, like in NCAA Baseball.

At the time of writing, the only two registered are the PCL American Conference and the PCL Pacific Conference.

Structs

Conference
A conference containing all details registered
ConferenceId
A u32 representing the ID of the conference, used in ConferencesRequest
ConferencesRequest
Returns a ConferencesResponse
ConferencesRequestBuilder
Use builder syntax to set the inputs and finish with build().
ConferencesResponse
Returns a Vec of Conferences
NamedConference
Conference with a name