Module division

Module division 

A division, like the AL East or NL West.

These are created for every league, not just the MLB and contain important division-specific information like num_playoff_teams, has_wildcard and active.

Structs

Division
A complete division of info, returned from DivisionsResponse
DivisionId
A u32 representing the ID of the division
DivisionsRequest
Returns a DivisionsResponse
DivisionsRequestBuilder
Use builder syntax to set the inputs and finish with build().
DivisionsResponse
A Vec of Divisions
NamedDivision
A division with a name.