Module draft

Module draft 

Draft endpoint data. Picks, rounds, etc.

Structs

DraftPick
An individual draft pick.
DraftProspectsRequest
This request gives a list of prospects.
DraftProspectsRequestBuilder
Use builder syntax to set the inputs and finish with build().
DraftProspectsResponse
Returns a Vec of DraftPicks for the prospects.
DraftRequest
This request sorts into rounds
DraftRequestBuilder
Use builder syntax to set the inputs and finish with build().
DraftRequestLatest
Returns a DraftResponse
DraftRequestLatestBuilder
Use builder syntax to set the inputs and finish with build().
DraftResponse
Returns a DraftYear.
DraftRound
A round of DraftPicks
DraftYear
A collection of DraftRounds in a year’s draft.
School
eBISPersonId
Different from PersonId.

Enums

DraftType