DraftRequestBuilder

Struct DraftRequestBuilder 

pub struct DraftRequestBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> DraftRequestBuilder<S>

pub fn build(self) -> DraftRequest
where S: IsComplete,

Finish building and return the requested object

pub fn year(self, value: impl Into<SeasonId>) -> DraftRequestBuilder<SetYear<S>>
where S::Year: IsUnset,

Optional (Some / Option setters).

Year of the draft.

pub fn maybe_year( self, value: Option<impl Into<SeasonId>>, ) -> DraftRequestBuilder<SetYear<S>>
where S::Year: IsUnset,

Optional (Some / Option setters).

Year of the draft.

pub fn limit(self, value: impl Into<u32>) -> DraftRequestBuilder<SetLimit<S>>
where S::Limit: IsUnset,

Optional (Some / Option setters).

Number of results to return.

pub fn maybe_limit( self, value: Option<impl Into<u32>>, ) -> DraftRequestBuilder<SetLimit<S>>
where S::Limit: IsUnset,

Optional (Some / Option setters).

Number of results to return.

pub fn offset(self, value: impl Into<u32>) -> DraftRequestBuilder<SetOffset<S>>
where S::Offset: IsUnset,

Optional (Some / Option setters).

Offset in the results (used for pagination).

pub fn maybe_offset( self, value: Option<impl Into<u32>>, ) -> DraftRequestBuilder<SetOffset<S>>
where S::Offset: IsUnset,

Optional (Some / Option setters).

Offset in the results (used for pagination).

pub fn round(self, value: impl Into<u32>) -> DraftRequestBuilder<SetRound<S>>
where S::Round: IsUnset,

Optional (Some / Option setters).

Draft round.

pub fn maybe_round( self, value: Option<impl Into<u32>>, ) -> DraftRequestBuilder<SetRound<S>>
where S::Round: IsUnset,

Optional (Some / Option setters).

Draft round.

pub fn drafted_only( self, value: impl Into<bool>, ) -> DraftRequestBuilder<SetDraftedOnly<S>>
where S::DraftedOnly: IsUnset,

Optional (Some / Option setters).

Include only successfully drafted players

pub fn maybe_drafted_only( self, value: Option<impl Into<bool>>, ) -> DraftRequestBuilder<SetDraftedOnly<S>>
where S::DraftedOnly: IsUnset,

Optional (Some / Option setters).

Include only successfully drafted players

pub fn last_name( self, value: impl Into<char>, ) -> DraftRequestBuilder<SetLastName<S>>
where S::LastName: IsUnset,

Optional (Some / Option setters).

Filter players by the first character of their last name.

pub fn maybe_last_name( self, value: Option<impl Into<char>>, ) -> DraftRequestBuilder<SetLastName<S>>
where S::LastName: IsUnset,

Optional (Some / Option setters).

Filter players by the first character of their last name.

pub fn school(self, value: impl Into<char>) -> DraftRequestBuilder<SetSchool<S>>
where S::School: IsUnset,

Optional (Some / Option setters).

Filter players by the first character of their school they were drafted from.

pub fn maybe_school( self, value: Option<impl Into<char>>, ) -> DraftRequestBuilder<SetSchool<S>>
where S::School: IsUnset,

Optional (Some / Option setters).

Filter players by the first character of their school they were drafted from.

pub fn position( self, value: impl Into<PositionCode>, ) -> DraftRequestBuilder<SetPosition<S>>
where S::Position: IsUnset,

Optional (Some / Option setters).

Filter players by their position.

pub fn maybe_position( self, value: Option<impl Into<PositionCode>>, ) -> DraftRequestBuilder<SetPosition<S>>
where S::Position: IsUnset,

Optional (Some / Option setters).

Filter players by their position.

pub fn team_id( self, value: impl Into<TeamId>, ) -> DraftRequestBuilder<SetTeamId<S>>
where S::TeamId: IsUnset,

Optional (Some / Option setters).

Filter players by the team they were drafted by.

pub fn maybe_team_id( self, value: Option<impl Into<TeamId>>, ) -> DraftRequestBuilder<SetTeamId<S>>
where S::TeamId: IsUnset,

Optional (Some / Option setters).

Filter players by the team they were drafted by.

pub fn home_country( self, value: impl Into<String>, ) -> DraftRequestBuilder<SetHomeCountry<S>>
where S::HomeCountry: IsUnset,

Optional (Some / Option setters).

Filter players by their home country.

pub fn maybe_home_country( self, value: Option<impl Into<String>>, ) -> DraftRequestBuilder<SetHomeCountry<S>>
where S::HomeCountry: IsUnset,

Optional (Some / Option setters).

Filter players by their home country.

pub fn player_id( self, value: impl Into<PersonId>, ) -> DraftRequestBuilder<SetPlayerId<S>>
where S::PlayerId: IsUnset,

Optional (Some / Option setters).

Filter for a specific player id.

pub fn maybe_player_id( self, value: Option<impl Into<PersonId>>, ) -> DraftRequestBuilder<SetPlayerId<S>>
where S::PlayerId: IsUnset,

Optional (Some / Option setters).

Filter for a specific player id.