Module game

Module game 

The thing you’re most likely here for.

This module itself acts like [crate::types] but for misc game-specific types as there are many.

Structs

ActionPlayDetails
ApplicablePlayMatchupSplits
Batter, Pitcher, and Men-On-Base splits; unknown type.
AtBatCount
The balls and strikes in a given at bat. Along with the number of outs (this technically can change during the AB due to pickoffs etc)
BattingOrderIndex
A position in the batting order, 1st, 2nd, 3rd, 4th, etc.
Boxscore
See [self]
BoxscoreRequest
BoxscoreRequestBuilder
Use builder syntax to set the inputs and finish with build().
BoxscoreStatCollection
Hitting, Pitching, and Fielding stats.
CompletedPlayDetails
Information supplied to PlayDetails when the play is complete
Decisions
Decisions of winner & loser (and potentially the save)
GameDateTime
Date & Time of the game. Note that the time is typically rounded to the hour and the :07, :05 on the hour is for the first pitch, which is a different timestamp.
GameId
A u32 representing a baseball game. Sport-independent
GameInfo
Misc
GamePace
GameStatLeaders
Game records in stats like exit velocity, hit distance, etc.
GameTags
Tags about a game, such as a perfect game in progress, no-hitter, etc.
GameTimestampsRequest
GameTimestampsRequestBuilder
Use builder syntax to set the inputs and finish with build().
HitData
Data regarding batted-balls
Inning
LabelledValue
Unparsed miscellaneous data.
LeagueGamePace
LeagueGamePaceRequest
LeagueGamePaceRequestBuilder
Use builder syntax to set the inputs and finish with build().
LeagueGamePaceResponse
Linescore
An inning by inning record of the game’s scoring.
LinescoreDefense
Current defense in the linescore, note that it also contains their offense too.
LinescoreInningRecord
A record of RHE from both teams in a single inning.
LinescoreOffense
Current offense in the linescore
LinescoreRequest
Returns a Linescore
LinescoreRequestBuilder
Use builder syntax to set the inputs and finish with build().
LiveFeedData
General information about the game
LiveFeedDataMeta
More specific information about the “game”, child of LiveFeedData
LiveFeedLiveData
Live data about the game – i.e. stuff that changes as the game goes on.
LiveFeedMetadata
Metadata about the game, often not useful.
LiveFeedRequest
Returns a LiveFeedResponse
LiveFeedRequestBuilder
Use builder syntax to set the inputs and finish with build().
LiveFeedResponse
See [self]
NoPitchPlayDetails
Official
PickoffPlayDetails
PitchData
Statistical data regarding a pitch.
PitchPlayDetails
Play
The play(s) within an “At-Bat”
PlayAbout
Miscallaneous data regarding a play
PlayByPlayRequest
PlayByPlayRequestBuilder
Use builder syntax to set the inputs and finish with build().
PlayDetails
The result of a play, such as a Strikeout, Home Run, etc.
PlayEventCommon
PlayMatchup
Hitter & Pitcher matchup information
PlayStream
Meant for active & live games, gives a streamable version of the plays in a game.
PlayerGameStatusFlags
Various flags about the player in the current game
PlayerWithGameData
A person with some potentially useful information regarding their performance in the current game.
Plays
A collection of plays, often a whole game’s worth.
RHE
The classic “R | H | E” and LOB in a scoreboard.
ReviewData
Data regarding replay reviews; present on Play, not PlayEvent.
RunnerCredit
Fielder credits to outs
RunnerData
Data regarding a baserunner.
RunnerDetails
Details about the runner’s movement
RunnerMovement
Data regarding the basepath of a runner
SectionedLabelledValues
SimplifiedTimestamp
Represents a UTC datetime in a very simple format, ex: 20251231_235959
SportGamePace
SportGamePaceRequest
SportGamePaceRequestBuilder
Use builder syntax to set the inputs and finish with build().
SportGamePaceResponse
StatcastHitData
Statcast data regarding batted balls, only sometimes present.
StepoffPlayDetails
TeamGamePace
TeamGamePaceRequest
TeamGamePaceRequestBuilder
Use builder syntax to set the inputs and finish with build().
TeamGamePaceResponse
TeamReviewData
Review usage for each team and if the game supports challenges.
TeamWithGameData
A team with some potentially useful information regarding their performance in the current game.
TopPerformer
One of three “top performers” of the game, measured by game score.
WeatherConditions
General weather conditions, temperature, wind, etc.

Enums

Base
ContactHardness
CreditKind
Statistical credits to fielders; putouts, assists, etc.
DoubleHeaderKind
Double-header information.
InningHalf
Half of the inning.
MovementReason
Reasons for baserunner movement
OfficialType
PlayEvent
An “indivisible” play, such as pickoff, pitch, stolen base, etc.
PlayStreamEvent
An event in a game, such as the game starting, ending, a Play (At-Bat) starting, or a PlayEvent occuring, or a challenge on a play or play event.

Functions

deserialize_review_data
Errors

Type Aliases

GameTimestampsResponse