pub enum CreditKind {
Putout,
Assist,
OutfieldAssist,
FieldedBall,
FieldingError,
ThrowingError,
Deflection,
Touch,
DroppedBallError,
DefensiveShiftViolation,
Interference,
CatchersInterference,
}Expand description
Statistical credits to fielders; putouts, assists, etc.
Variants
Putout
Assist
OutfieldAssist
FieldedBall
The fielder just, fielded the ball, no outs or anything.
FieldingError
ThrowingError
Deflection
Touch
They literally touched it, no deflection, just a tap.
DroppedBallError
DefensiveShiftViolation
Interference
CatchersInterference