pub struct BattingOrderIndex {
pub major: usize,
pub minor: usize,
}Expand description
A position in the batting order, 1st, 2nd, 3rd, 4th, etc.
Note that this number is split in two, the general batting order position is the major while if there is a lineup movement then the player would have an increased minor since they replace an existing batting order position.
Example: Alice bats 1st (major = 1, minor = 0) Bob pinch hits and bats 1st for Alice (major = 1, minor = 1) Alice somehow hits again (major = 1, minor = 0) Charlie pinch runs and takes over from then on (major = 1, minor = 2)
Note: These minors are Displayed incremented one more than is done internally, so (major = 1, minor = 1) displays as 1st (2).
Fields
major: usizeminor: usizeTrait Implementations
Sourceimpl Clone for BattingOrderIndex
impl Clone for BattingOrderIndex
Sourcefn clone(&self) -> BattingOrderIndex
fn clone(&self) -> BattingOrderIndex
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BattingOrderIndex
impl Debug for BattingOrderIndex
Sourceimpl<'de> Deserialize<'de> for BattingOrderIndex
impl<'de> Deserialize<'de> for BattingOrderIndex
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for BattingOrderIndex
impl Display for BattingOrderIndex
Sourceimpl PartialEq for BattingOrderIndex
impl PartialEq for BattingOrderIndex
impl Copy for BattingOrderIndex
impl StructuralPartialEq for BattingOrderIndex