GameDateTime

Struct GameDateTime 

pub struct GameDateTime {
    pub datetime: DateTime<Utc>,
    pub original_date: NaiveDate,
    pub official_date: NaiveDate,
    pub sky: DayNight,
    pub time: NaiveTime,
    pub ampm: DayHalf,
}
Date & Time of the game.

Fields

datetime: DateTime<Utc>

The date and time of the game. Note that the time is typically rounded to the hour and the :07, :05 on the hour is for the first pitch, which is a different timestamp.

original_date: NaiveDate

The original planned date of the game

official_date: NaiveDate

The currently set “date” of the game.

sky: DayNight

Day or night

time: NaiveTime

The local 12-hour time of the game

ampm: DayHalf

AM or PM; use DayHalf::into_24_hour_time to convert to 24-hour local time.