PitchData

Struct PitchData 

pub struct PitchData {
Show 33 fields pub release_speed: f64, pub plate_speed: f64, pub sz_bot: f64, pub sz_top: f64, pub sz_wid: f64, pub sz_dep: f64, pub aX: f64, pub aY: f64, pub aZ: f64, pub pfxX: f64, pub pfxZ: f64, pub pX: f64, pub pZ: f64, pub vX0: f64, pub vY0: f64, pub vZ0: f64, pub x0: f64, pub y0: f64, pub z0: f64, pub x: f64, pub y: f64, pub break_angle: f64, pub break_length: f64, pub induced_vertical_movement: f64, pub vertical_drop: f64, pub horizontal_movement: f64, pub depth_break: f64, pub spin_rate: f64, pub spin_axis: f64, pub zone: StrikeZoneSection, pub type_confidence: f64, pub time_to_plate: f64, pub extension: f64,
}
Statistical data regarding a pitch.

Some acronyms are an existing spec, best to keep with that.

Fields

release_speed: f64

Velocity measured at release, measured in mph

plate_speed: f64

Velocity measured crossing home plate, measured in mph

sz_bot: f64

Height above home plate for the bottom of the hitter’s strike zone

Measured in feet.

sz_top: f64

Height above home plate for the top of the hitter’s strike zone

Measured in feet.

sz_wid: f64

Width of the strike zone

Measured in inches.

sz_dep: f64

Depth of the strike zone

Measured in inches.

aX: f64

Acceleration of the pitch near release, horizontal movement axis, catchers perspective (positive means RHP sweep)

Measured in feet/s^2.

aY: f64

Acceleration of the pitch near release, depth axis, catchers perspective (positive means deceleration)

Measured in feet/s^2.

aZ: f64

Acceleration of the pitch near release, vertical movement axis, catchers perspective (positive means literal carry)

Measured in feet/s^2.

pfxX: f64

Might be broken, use horizontal_movement instead

Horizontal movement of the pitch between the release point and home plate, catchers perspective (positive means RHP sweep) as compared to a theoretical pitch thrown at with the same velocity vector and no spin-induced movement. This parameter is measured at y=40 feet regardless of the y0 value.

Measured in inches.

Does not account for seam-shifted wake!

pfxZ: f64

Might be broken, use vertical_drop instead

Vertical movement of the pitch between the release point and home plate, catchers perspective (positive means literal rise), as compared to a theoretical pitch thrown at with the same velocity vector and no spin-induced movement. This parameter is measured at y=40 feet regardless of the y0 value.

Measured in inches.

Does not account for seam-shifted wake!

pX: f64

Horizontal coordinate of the pitch as it crosses home plate, 0 is the middle of the plate. Catchers perspective, positive means arm-side for a RHP, negative means glove-side for a RHP.

Measured in feet.

pZ: f64

Vertical coordinate of the pitch as it crosses home plate, 0 is the plate itself

Measured in feet.

vX0: f64

Horizontal component of velocity out of the hand, catchers perspective, positive means RHP glove-side.

Measured in feet per second.

vY0: f64

Depth component of velocity out of the hand, catchers perspective, positive means the ball isn’t going into centerfield.

Measured in feet per second.

vZ0: f64

Vertical component of velocity out of the hand, measured in feet per second.

Measured in feet per second.

x0: f64

X coordinate of pitch at release

Measured in feet

y0: f64

Y coordinate of pitch at release, typically as close to 50 as possible.

Measured in feet

z0: f64

Z coordinate of pitch at release

Measured in feet

x: f64

No clue.

y: f64

No clue.

break_angle: f64

No clue. Does not match theta angle of induced break vector. Consistently 36.0. Strange.

break_length: f64

No clue. Does not match length of induced break vector.

induced_vertical_movement: f64

Standard metric, amount of vertical movement induced.

Measured in inches

vertical_drop: f64

Standard metric, amount of vertical movement the pitch has (including gravity).

Measured in inches

horizontal_movement: f64

Standard metric, amount of horizontal movement the pitch has.

Measured in inches

depth_break: f64

No clue. Thought to be the amount of depth-based movement (acceleration), but it’s consistently 24.0. Strange.

spin_rate: f64

RPMs out of the hand

spin_axis: f64

Measured in degrees.

0 means complete topspin. 180 means complete backspin. 90 means complete sidespin (RHP sweeper). 270 means complete sidespin (elite RHP changeup).

~225 is your average RHP fastball.

zone: StrikeZoneSectiontype_confidence: f64

AI model confidence about pitch type designation.

Sometimes greater than 1.0

time_to_plate: f64

Time from out of the hand to crossing the plate.

Measured in seconds

extension: f64

Extension

Measured in feet