PlayAbout

Struct PlayAbout 

pub struct PlayAbout {
    pub at_bat_idx: usize,
    pub inning_half: InningHalf,
    pub inning: Inning,
    pub start_timestamp: NaiveDateTime,
    pub end_timestamp: NaiveDateTime,
    pub is_complete: bool,
    pub is_scoring_play: Option<bool>,
    pub has_review: bool,
    pub has_out: bool,
    pub captivating_index: usize,
    /* private fields */
}
Miscallaneous data regarding a play

Fields

at_bat_idx: usize

Ordinal at bat of the game (starts at 0)

inning_half: InningHalf

The inning half this play is in

inning: Inning

The inning this play is in

start_timestamp: NaiveDateTime

The timestamp that this play begins; includes milliseconds

end_timestamp: NaiveDateTime

The timestamp that this play ends at; includes milliseconds

is_complete: bool

Whether the play is “complete” or not, i.e. opposite of ongoing.

Once a play is complete it cannot be edited

is_scoring_play: Option<bool>

Whether the play itself is scoring, such as a Home Run.

Note that Plays that include PlayEvents that score runs that are not part of the Play (such as stealing home) do not indicate this as true.

This is the predicate for Plays::scoring_plays

has_review: bool

Whether the play has a replay review occur. Note that At-Bats can have multiple challenges occur.

has_out: bool

Whether the play has counted towards an out so far.

todo: check if includes play events like pickoffs.

captivating_index: usize

Ordinal ranking for +/- WPA effect.

1 means largest effect on WPA, 2 means second most, etc.