PlayStream

Struct PlayStream 

pub struct PlayStream { /* private fields */ }
Meant for active & live games, gives a streamable version of the plays in a game.

The PlayStream is meant to be for consistently polling the MLB API for live play-by-play updates. The list of events can be seen on PlayStreamEvent

Note that the Linescore and Boxscore are not timed to the current state of the game as of the event, to achieve that it is recommended the timecode argument to live feed and iterate through the timecodes on its endpoint; however is much slower, or using diffPatch.

Examples

PlayStream::new(/* game id */).run(|event: PlayStreamEvent, meta: &LiveFeedMetadata, data: &LiveFeedData, linescore: &Linescore, boxscore: &Boxscore| {
    match event {
        PlayStreamEvent::Start => println!("Start"),
        PlayStreamEvent::StartPlay(play) => println!("{} vs. {}", play.matchup.batter.full_name, play.matchup.pitcher.full_name),
        PlayStreamEvent::PlayEvent(play_event, _play) => {
            match play_event {
                PlayEvent::Action { details, .. } => println!("{}", details.description),
                PlayEvent::Pitch { details, common, .. } => println!("{} -> {}", details.call, common.count),
                PlayEvent::Stepoff { .. } => println!("Stepoff"),
                PlayEvent::NoPitch { .. } => println!("No Pitch"),
                PlayEvent::Pickoff { .. } => println!("Pickoff"),
            }
        },
        PlayStreamEvent::PlayEventReviewStart(review, _play_event, _play) => println!("PlayEventReviewStart; {}", review.review_type),
        PlayStreamEvent::PlayEventReviewEnd(review, _play_event, _play) => println!("PlayEventReviewEnd; {}", review.review_type),
        PlayStreamEvent::PlayReviewStart(review, _play) => println!("PlayReviewStart; {}", review.review_type),
        PlayStreamEvent::PlayReviewEnd(review, _play) => println!("PlayReviewEnd; {}", review.review_type),
        PlayStreamEvent::EndPlay(play) => println!("{}", play.result.completed_play_details.as_ref().expect("Completed play").description),
        PlayStreamEvent::GameEnd(_, _) => println!("GameEnd"),
    }
}).await?;

Implementations

Source

impl PlayStream

pub fn new(game_id: impl Into<GameId>) -> Self

Source

impl PlayStream

pub async fn run<F: AsyncFnMut(PlayStreamEvent<'_>, &LiveFeedMetadata, &LiveFeedData, &Linescore, &Boxscore) -> Result<ControlFlow<()>, Error>>( self, f: F, ) -> Result<(), Error>

Runs through plays until the game is over.

Errors

See request::Error

pub async fn run_with_custom_error<E: From<Error>, F: AsyncFnMut(PlayStreamEvent<'_>, &LiveFeedMetadata, &LiveFeedData, &Linescore, &Boxscore) -> Result<ControlFlow<()>, E>>( self, f: F, ) -> Result<(), E>

Variant of the run function that allows for custom error types.

Errors

See request::Error

pub async fn with_presupplied_feed<E: From<Error>, F: AsyncFnMut(PlayStreamEvent<'_>, &LiveFeedMetadata, &LiveFeedData, &Linescore, &Boxscore) -> Result<ControlFlow<()>, E>>( feed: LiveFeedResponse, f: F, ) -> Result<(), E>

Variant of the run function that begins with a pre-supplied LiveFeedResponse, useful if preprocessing was done before the play stream.

Errors

See request::Error