pub struct StatcastHitData {
pub exit_velocity: f64,
pub launch_angle: f64,
pub distance: f64,
}Expand description
Statcast data regarding batted balls, only sometimes present.
Fields
exit_velocity: f64Speed of the ball as it leaves the bat
Measured in mph
launch_angle: f64Vertical Angle in degrees at which the ball leaves the bat.
Measured in degrees
distance: f64Distance the ball travels before being caught or rolling.
Measured in feet