Module meta

Module meta 

An abstraction over endpoints that contain fixed data, such as GameTypes, JobTypes, etc.

For types in which quick accessibility is important (and there are not tons of variants), they will be represented as an enum (GameType).

For types which have many variants and ones that would be constantly updating, they are represented as Vec<struct>s (SituationCode).

These types implement MetaKind and Requestable for ease of use.

Some of these types will have id-only variants in most responses, in which you can request details using Requestable; Position.

Structs

BaseballStat
A Baseball Stat; "hits", "strikeOuts", "xWoba", etc.
BaseballStatId
A String ID for a BaseballStat
GameStatus
GameStatusId
A String representing the GameStatus
JobType
Different types of baseball jobs; Umpires, Coaches, etc.
JobTypeId
A String representing a JobType.
Language
LanguageId
A u32 representing a Language
LeagueLeaderTypeId
A String representing a stat a player can lead the league in.
LogicalEventId
A String representing a Game Logic Event, like a count change, new batter, game status change, etc.
MetaRequest
Returns MetaResponse<T>.
MetaResponse
Generalized response for the meta endpoints.
Metric
A measurement thing; typically EV, LA, pitch velocity, spin rate, etc.
MetricId
A u32 representing a Metric
NamedMetric
A Metric with a name
NamedPosition
A Position with a name.
PitchCode
A detailed struct representing everything logic-related that happened with a pitch.
PitchCodeId
A String representing a pitch, such as “F” for Foul, “S” for Swinging Strike, etc.
PitchType
A detailed struct describing a pitch type.
PitchTypeId
A String representing pitch types, "FF" for Four-Seam Fastball, "CU" for Curveball, etc.
Platform
A detailed struct representing a Platform
PlatformId
A String representing an electronic platform
Position
A Position with every piece of data you could describe about it.
PositionCode
A String representing a position on the field, such as Pitcher, 1st Baseman, etc. These values use 1-9, so Pitcher = “1”, etc.
ReviewReason
A detailed struct representing a reviewable play.
ReviewReasonId
A review on a play (These codes often are just single letters and mean nothing and only useful for lookup purposes.)
ScheduleEventType
A detailed struct representing an event in the schedule.
ScheduleEventTypeId
A String code representing a ScheduleEventType
SituationCode
A specific situation in a game
SituationCodeId
A String representing a situation, such as c00 for a 0-0 count
SkyDescription
A detailed struct representing the sky conditions
SkyDescriptionId
A String describing the conditions of the sky
StatType
A String representing a specific type of stat collection
WindDirection
A detailed struct representing the direction wind is going.
WindDirectionId
A String representing a direction the wind is going

Enums

AbstractGameCode
Basic game status code, describes whether the game is in the past (finished), present (underway), or future (scheduled).
CodedGameState
Detailed game status (use AbstractGameCode for simpler responses)
DayNight
Whether the sky shows daytime or nighttime
EventType
EventTypeFromStrError
GameType
HitTrajectory
Different coarse definitions of how a ball is hit – likely up to scorers interpretation.
RosterType
Types of roster definitions
SituationCodeCategory
SituationCodeFilter
Filters searching through situation codes to filter with multiple situation codes.
StandingsType
Different types of standings
StatGroup
Hitting, Pitching, etc.
Unit
A unit of measurement

Traits

MetaKind
Represents a type that is metadata.