pub enum CodedGameState {
Scheduled,
PreGame,
InProgress,
ManagerChallenge,
UmpireReview,
Postponed,
Cancelled,
Finished,
Suspended,
Forfeit,
Writing,
Unknown,
}Expand description
Detailed game status (use AbstractGameCode for simpler responses)
Variants
Scheduled
Game has not begun, but is scheduled to occur
PreGame
Game is currently undergoing pregame activities (such as warming up, or a slight delay before start)
InProgress
Game is underway.
ManagerChallenge
Manager is submitting a challenge
UmpireReview
Umpires are reviewing a play
Postponed
Game is postponed; has not begun but moved to a later date – typically double-header.
Cancelled
Game is canceled and never began. Removed from total # of games played, no rescheduling.
Finished
Game was finished.
Suspended
Game was suspended, will be played on a later date.
Forfeit
Game was forfeited.
Writing
Game is being written?? (Likely means that the official scorer is in the process of doing the finishing touches)
Unknown
Game state is unknown (typically assume the game was completed)