EventType

Enum EventType 

pub enum EventType {
Show 73 variants BatterTimeout, MoundVisit, GameAdvisory, PitchingSubstitution, DefensiveSwitch, DefensiveSubstitution, OffensiveSubstitution, UmpireSubstitution, PickoffError1B, PickoffError2B, PickoffError3B, PitcherStepOff, FanInterference, BatterHandednessSwitch, PitcherHandednessSwitch, Ejection, NoPitch, DisengagementViolation, FieldOut, ForceOut, FieldersChoice, FieldersChoiceFieldOut, Strikeout, StrikeoutDoublePlay, StrikeoutTriplePlay, SacrificeBunt, SacrificeFly, GroundedIntoDoublePlay, GroundedIntoTriplePlay, DoublePlay, TriplePlay, OtherOut, FieldError, Error, CaughtStealing, CaughtStealing2B, CaughtStealing3B, CaughtStealingHome, CaughtStealingDoublePlay, SacrificeFlyDoublePlay, SacrificeBuntDoublePlay, Injury, PriorRulingPending, RulingPending, AtBatStart, Pickoff1B, Pickoff2B, Pickoff3B, PickoffCaughtStealing2B, PickoffCaughtStealing3B, PickoffCaughtStealingHome, BattersInterference, RunnersInterference, RunnersInterferenceDoublePlay, RunnerPlaced, Balk, Walk, IntentionalWalk, HitByPitch, Single, Double, Triple, HomeRun, StolenBase, StolenBase2B, StolenBase3B, StolenBaseHome, DefensiveIndifference, PassedBall, WildPitch, CatchersInterference, FieldersInterference, OtherAdvancement,
}

Variants



BatterTimeout

Batter requested timeout



MoundVisit

Any kind of mound visit, decrements MVR



GameAdvisory

Game Status Changes



PitchingSubstitution

Pitching substitution, only can occur during the inning half where the team is pitching



DefensiveSwitch

Switching existing fielder positions



DefensiveSubstitution

Swawp out fielder for new fielder off the bench



OffensiveSubstitution

Pinch-hitting



UmpireSubstitution

Swap out umpire



PickoffError1B

Pickoff that leads to an error at 1B



PickoffError2B

Pickoff that leads to an error at 2B



PickoffError3B

Pickoff that leads to an error at 3B



PitcherStepOff

Pitcher steps off the mound for a break



FanInterference

Fan interference in the play



BatterHandednessSwitch

Batter switches sides of the plate



PitcherHandednessSwitch

Pitcher switches handedness



Ejection

Person gets ejected



NoPitch

Official No Pitch



DisengagementViolation

Batter does not step in the box in time, or pitcher does not step in the box in time



FieldOut

Field out, such as a tag play



ForceOut

Force out, such as a simple groundout



FieldersChoice

Fielder’s Choice



FieldersChoiceFieldOut

Fielder’s Choice but a tag play



Strikeout

Not necessarily an out; check for is_out field on a runner to be false.



StrikeoutDoublePlay

Strike-em-out-throw-em-out, etc.



StrikeoutTriplePlay



SacrificeBunt

Sacrifice Bunt



SacrificeFly

Sacrifice Fly



GroundedIntoDoublePlay

Textbook



GroundedIntoTriplePlay

5-4-3, etc.



DoublePlay

Unique double plays that aren’t groundout + groundout



TriplePlay

Unique triple plays that aren’t groundout + groundout + groundout



OtherOut

Out so confusing the official scorer had no clue what to put



FieldError

Error in fielding



Error

Misc Error



CaughtStealing

Runner Caught Stealing; often seen in old data, base is included in the [PlayEvent] now.



CaughtStealing2B

Caught stealing second base



CaughtStealing3B

Caught stealing third base



CaughtStealingHome

Caught stealing home



CaughtStealingDoublePlay

Caught Stealing Double Play – not a strikeout double play. Such as a caught stealing at second, and a throw home to get a runner on third trying to score from the steal attempt.



SacrificeFlyDoublePlay

Sacrifice Fly that ends in a double play, but is also a successful sacrifice fly. Such as a runner on second and third and the runner on second trying to go to third but getting thrown out.



SacrificeBuntDoublePlay

Sacrifice bunt that leds to a double play



Injury

Player gets injury, delay of game



PriorRulingPending

Ruling is currently pending on the prior play, please wait.



RulingPending

Ruling is currently pending on the active play, please wait.



AtBatStart

Seemingly unused



Pickoff1B

Successful pickoff



Pickoff2B

Successful pickoff



Pickoff3B

Successful pickoff



PickoffCaughtStealing2B

Pickoff on a stolen base attempt, such as going too early and getting thrown out.



PickoffCaughtStealing3B

Pickoff on a stolen base attempt, such as going too early and getting thrown out.



PickoffCaughtStealingHome

Pickoff on a stolen base attempt, such as going too early and getting thrown out.



BattersInterference

Batter interferes with the play



RunnersInterference

Runner interferes with the play, such as kicking the ball.



RunnersInterferenceDoublePlay

Ex: Runner intentionally interferes with the play to not get someone on a later base out, but is so obvious that the umpires and official scorer rule both players out.



RunnerPlaced

Runner placed on a base, such as extra innings



Balk

Balk



Walk

Base on Balls



IntentionalWalk

Intentional Walk



HitByPitch

Hit by Pitch



Single

Single



Double

Double, could be ground-rule



Triple

Triple



HomeRun

Home Run, could be inside the park.



StolenBase

Stolen base, modern games include the base in the [PlayEvent].



StolenBase2B

Stolen second base



StolenBase3B

Stolen third base



StolenBaseHome

Stolen home



DefensiveIndifference

A stolen base but unchallenged by the defense; not counted as a SB.



PassedBall

Catcher fails at his job



WildPitch

Pitcher throws a ball so badly it gets away from the catcher



CatchersInterference

Catcher interferes with the play



FieldersInterference

Fielder interferes with the play



OtherAdvancement

Something so confusing that the Official Scorer has no clue what to call it.

Implementations

Source

impl EventType

pub const fn is_hit(self) -> bool

pub const fn is_plate_appearance(self) -> bool

pub const fn is_base_running_event(self) -> bool

pub const fn is_out(self) -> bool