pub enum HitTrajectory {
BuntGrounder,
BuntPopup,
BuntLineDrive,
LineDrive,
GroundBall,
FlyBall,
Popup,
}Expand description
Different coarse definitions of how a ball is hit – likely up to scorers interpretation.
Variants
Implementations
Sourceimpl HitTrajectory
impl HitTrajectory
Sourcepub const fn from_launch_angle(launch_angle: f64) -> Self
pub const fn from_launch_angle(launch_angle: f64) -> Self
Uses launch angle data to derive a hit trajectory.