SituationCodeCategory

Enum SituationCodeCategory 

pub enum SituationCodeCategory {
Show 18 variants Game, Month, Timeframe, DayOfWeek, Opponent, Venue, AtBat, GameScore, Inning, GameResult, BattingOrder, Runners, Position, Pitching, PitchCount, Outs, AtBatCount, PitchType,
}

Variants



Game

The environment the game is played in, turf, grass, day, night, home, away.



Month

The month the game is played in



Timeframe

The time in the schedule the game is played, pre-ASG, last 30 days, etc.



DayOfWeek

Day of the week



Opponent

What kind of opponent you’re facing, divisional, league, etc.



Venue

Venue-related filters.



AtBat

General At-Bat filters; LHB, RHP, etc.



GameScore

Scoring data, leading, trailing, how many runs they lead by, etc.



Inning

Inning filters; extra innings, first inning, etc.



GameResult

Game result; win, loss, previous was a win, etc.



BattingOrder

Batting order position



Runners

Runner positions on the bases



Position

Fielding Position



Pitching

Days of rest, starting, relieving, etc.



PitchCount

Pitch count filters.



Outs

None out, One out, Two out



AtBatCount

0-0 Count, 3-2 Count, etc.



PitchType

Type of pitch thrown