Module stats
mlb_api
1.0.3
Module stats
Module Items
Structs
In mlb_
api::
person
mlb_api
::
person
Module
stats
Gets the stats of a player for a single game.
Structs

Person
Single
Game
Stats
Request
Person
Single
Game
Stats
Request
Builder
Use builder syntax to set the inputs and finish with
build()
.
Person
Single
Game
Stats
Response
Single
Game
Stats
Single
Game
Stats
Simplified
Game
LogSplit
Single
Game
Stats
Simplified
Play
LogSplit
Single
Game
Stats
VsPlayer5Y
Split