Module schedule

Module schedule 

Schedules, typically the main entrypoint to navigate through games.

Modules

postseason
Postseason schedule info and endpoints.
tied
Tied games (?).

Macros

schedule_hydrations
Creates hydrations for a schedule

Structs

ScheduleDate
ScheduleGame
ScheduleRequest
ScheduleRequestBuilder
Use builder syntax to set the inputs and finish with build().
ScheduleResponse
SeriesData
Standings
TeamWithStandings
TeamWithStandingsGameScore

Traits

ScheduleHydrations