Module season

Module season 

Data about important dates in a season for a specific SportId.

When spring training starts, ends. Regular season dates, Postseason dates, ASG, etc.

Structs

QualificationMultipliers
Season
A season and it’s info - dependent on SportId. Stores multiple date ranges for different parts of the season (spring training, postseason, etc)
SeasonId
SeasonsRequest
Returns a SeasonsResponse
SeasonsRequestBuilder
Use builder syntax to set the inputs and finish with build().
SeasonsResponse
Returns a Vec of Seasons.

Enums

SeasonState
Current state of the season