Season

Struct Season 

pub struct Season {
    pub id: SeasonId,
    pub has_wildcard: bool,
    pub preseason: NaiveDateRange,
    pub spring: Option<NaiveDateRange>,
    pub season: NaiveDateRange,
    pub regular_season: NaiveDateRange,
    pub first_half_end: Option<NaiveDate>,
    pub all_star: Option<NaiveDate>,
    pub second_half_start: Option<NaiveDate>,
    pub postseason: Option<NaiveDateRange>,
    pub offseason: NaiveDateRange,
    pub qualification_multipliers: Option<QualificationMultipliers>,
}
A season and it’s info - dependent on SportId. Stores multiple date ranges for different parts of the season (spring training, postseason, etc)

These fields are arranged in a chronological order but the specification makes no guarantees that this order remain consistent.

Fields

id: SeasonIdhas_wildcard: bool

If the season has a wildcard system

preseason: NaiveDateRange

Preseason date range

spring: Option<NaiveDateRange>

Spring Training date range

season: NaiveDateRange

Full Season date range

regular_season: NaiveDateRange

Regular Season date range

first_half_end: Option<NaiveDate>

End of the first half of the season (if the season halves are defined)

all_star: Option<NaiveDate>

When the ASG is

second_half_start: Option<NaiveDate>

Start of the second half of the season (if the season halves are defined)

postseason: Option<NaiveDateRange>

When the postseason happens

offseason: NaiveDateRange

When the offseason is active (different from preseason)

qualification_multipliers: Option<QualificationMultipliers>