Module sport

Module sport 

Different “sports”; MLB, AAA, AA, A+, A, Rookieball, etc.

Macros

sports_hydrations
Creates hydrations for a sport

Structs

Sport
A detailed struct representing information about a sport (or Organized Baseball Level)
SportId
A u32 representing the ID of the sport; SportId::MLB = 1
SportsRequest
Returns a SportsResponse
SportsRequestBuilder
Use builder syntax to set the inputs and finish with build().
SportsResponse
A Vec of Sports.

Traits

SportsHydrations