Module standings

Module standings 

Standings of a team, wins, losses, etc

Macros

standings_hydrations
Creates hydrations for a standings request

Structs

DivisionalRecordSplit
DivisionalStandings
TeamRecords per division. last_updated field might be useful for caching
GamesBack
LeagueRecordSplit
Record
RecordSplit
A team’s record, filtered by the RecordSplitKind.
RecordSplits
Different record splits depending on the Division, League, RecordSplitKind, etc.
StandingsRequest
Returns a StandingsResponse.
StandingsRequestBuilder
Use builder syntax to set the inputs and finish with build().
StandingsResponse
A Vec of DivisionalStandings
Streak
TeamRecord
Main bulk of the response; the team’s record and standings information. Lots of stuff here.

Enums

ClinchKind
Different indicators for clinching the playoffs.
RecordSplitKind
StreakKind
A game outcome for streak purposes

Traits

StandingsHydrations