#[repr(u8)]pub enum ClinchKind {
Bye = 4,
Divisional = 3,
WildCard = 2,
Postseason = 1,
None = 0,
}Expand description
Different indicators for clinching the playoffs.
Note: This assumes the modern postseason format, if you are dealing with older formats the predicates below are not guaranteed to work.
Variants
Bye = 4
The Team has clinched a top seed guaranteeing a bye.
Divisional = 3
The team has clinched their position in the division.
WildCard = 2
The team has clinched a wild card position.
Postseason = 1
The team has clinched a position in the postseason, however that specific placement is unknown.
None = 0
Team has not clinched the postseason.
Implementations
Sourceimpl ClinchKind
impl ClinchKind
Sourcepub const fn clinched_postseason(self) -> bool
pub const fn clinched_postseason(self) -> bool
Whether a team is guaranteed to play in the postseason.
Examples
use mlb_api::standings::ClinchKind;
assert!( ClinchKind::Bye.clinched_postseason());
assert!( ClinchKind::WildCard.clinched_postseason());
assert!( ClinchKind::Postseason.clinched_postseason());
assert!(! ClinchKind::None.clinched_postseason());Sourcepub const fn is_final(self) -> bool
pub const fn is_final(self) -> bool
Whether the ClinchKind is a final decision and cannot be changed.
Examples
use mlb_api::standings::ClinchKind;
assert!( ClinchKind::Bye.is_final());
assert!( ClinchKind::WildCard.is_final());
assert!(! ClinchKind::Postseason.is_final());
assert!(! ClinchKind::None.is_final());Sourcepub const fn guaranteed_in_wildcard(self) -> bool
pub const fn guaranteed_in_wildcard(self) -> bool
Whether the team will play in a Wild Card Series.
If the postseason decision is not final, the team is considered to not play in the wild card round. If you want different behavior use Self::guaranteed_in_wildcard.
Examples
use mlb_api::standings::ClinchKind;
assert!(! ClinchKind::Bye.guaranteed_in_wildcard());
assert!( ClinchKind::Divisional.guaranteed_in_wildcard());
assert!( ClinchKind::WildCard.guaranteed_in_wildcard());
assert!(! ClinchKind::None.guaranteed_in_wildcard());
assert!(! ClinchKind::Postseason.guaranteed_in_wildcard());Sourcepub const fn potentially_in_wildcard(self) -> bool
pub const fn potentially_in_wildcard(self) -> bool
Whether the team has a possibility of playing in the Wild Card Series.
Examples
use mlb_api::standings::ClinchKind;
assert!(! ClinchKind::Bye.guaranteed_in_wildcard());
assert!( ClinchKind::Divisional.guaranteed_in_wildcard());
assert!( ClinchKind::WildCard.guaranteed_in_wildcard());
assert!( ClinchKind::None.guaranteed_in_wildcard());
assert!( ClinchKind::Postseason.guaranteed_in_wildcard());Trait Implementations
Sourceimpl Clone for ClinchKind
impl Clone for ClinchKind
Sourcefn clone(&self) -> ClinchKind
fn clone(&self) -> ClinchKind
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ClinchKind
impl Debug for ClinchKind
Sourceimpl Default for ClinchKind
impl Default for ClinchKind
Sourcefn default() -> ClinchKind
fn default() -> ClinchKind
Sourceimpl<'de> Deserialize<'de> for ClinchKind
impl<'de> Deserialize<'de> for ClinchKind
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Ord for ClinchKind
impl Ord for ClinchKind
Sourcefn cmp(&self, other: &ClinchKind) -> Ordering
fn cmp(&self, other: &ClinchKind) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for ClinchKind
impl PartialEq for ClinchKind
Sourceimpl PartialOrd for ClinchKind
impl PartialOrd for ClinchKind
impl Copy for ClinchKind
impl Eq for ClinchKind
impl StructuralPartialEq for ClinchKind