RecordSplitKind

Enum RecordSplitKind 

pub enum RecordSplitKind {
Show 18 variants Home, Away, Left, LeftHome, LeftAway, Right, RightHome, RightAway, LastTen, ExtraInnings, OneRun, Winners, Day, Night, Grass, Turf, xWinLoss, xWinLossSeason,
}

Variants



Home

Games as the home team



Away

Games as the away team



Left

Games in which you are “left” (?) A



LeftHome

Games in which you are “left” && you are the home team



LeftAway

Games in which you are “left” && you are the away team



Right

Games in which you are “right” (?)



RightHome

Games in which you are “right” and the home team



RightAway

Games in which you are “right” and the away team



LastTen

Last 10 games of the season as of the current date. Note that early in the season, Record::games_played may be < 10



ExtraInnings

Games that went to extra innings.



OneRun

Games won or lost by one run



Winners

what?



Day

Day games



Night

Night games



Grass

Games played on grass



Turf

Games played on turf



xWinLoss

Expected record using pythagorean expected win loss pct

This value is calculated as a percentage and multiplied by the number of games that have been played.



xWinLossSeason

Expected record for the season using pythagorean expected win loss pct

This value is calculated as a percentage and multiplied by the number of games in the season.