babip

Function babip 

pub fn babip(
    hits: Result<CountingStat, OmittedStatError>,
    home_runs: Result<CountingStat, OmittedStatError>,
    at_bats: Result<CountingStat, OmittedStatError>,
    strikeouts: Result<CountingStat, OmittedStatError>,
    sac_flies: Result<CountingStat, OmittedStatError>,
) -> ThreeDecimalPlaceRateStat
BABIP - Batting Average on Balls in Play

Describes the batting average, only sampling balls that are in play.
This stat is typically used as a “luck-indicator” stat. Being around .400 or greater is generally considered lucky, however below .300 or so is considered unlucky.
Using expected stats (ex: xwOBA or xAVG) and comparing to the actual-outcome stats (ex: wOBA and AVG) generally gives a clearer indicator of luck, however these numbers are harder to find.

Hitters: Higher is better. Pitchers: Lower is better.