ops

Function ops 

pub fn ops(
    obp: Result<ThreeDecimalPlaceRateStat, OmittedStatError>,
    slg: Result<ThreeDecimalPlaceRateStat, OmittedStatError>,
) -> ThreeDecimalPlaceRateStat
OPS - On-Base Plus Slugging

Adds OBP and SLG values together to make a new stat (yes, this means both components are weighted equally) Typically this is used as a trivial way to rank performance, however if possible, using wOBA-like stats is recommended as they are generally more accurate.

Hitters: Higher is better. Pitchers: Lower is better.