StatLeadersRequestBuilder

Struct StatLeadersRequestBuilder 

pub struct StatLeadersRequestBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> StatLeadersRequestBuilder<S>

pub fn build(self) -> StatLeadersRequest
where S: IsComplete,

Finish building and return the requested object

pub fn stats( self, value: Vec<BaseballStatId>, ) -> StatLeadersRequestBuilder<SetStats<S>>
where S::Stats: IsUnset,

Required.

pub fn stat_group( self, value: StatGroup, ) -> StatLeadersRequestBuilder<SetStatGroup<S>>
where S::StatGroup: IsUnset,

Optional (Some / Option setters).

pub fn maybe_stat_group( self, value: Option<StatGroup>, ) -> StatLeadersRequestBuilder<SetStatGroup<S>>
where S::StatGroup: IsUnset,

Optional (Some / Option setters).

pub fn season( self, value: impl Into<SeasonId>, ) -> StatLeadersRequestBuilder<SetSeason<S>>
where S::Season: IsUnset,

Optional (Some / Option setters).

pub fn maybe_season( self, value: Option<impl Into<SeasonId>>, ) -> StatLeadersRequestBuilder<SetSeason<S>>
where S::Season: IsUnset,

Optional (Some / Option setters).

pub fn sport_id( self, value: impl Into<SportId>, ) -> StatLeadersRequestBuilder<SetSportId<S>>
where S::SportId: IsUnset,

Optional (Some / Option setters). Default: <SportId as Default>::default().

pub fn maybe_sport_id( self, value: Option<impl Into<SportId>>, ) -> StatLeadersRequestBuilder<SetSportId<S>>
where S::SportId: IsUnset,

Optional (Some / Option setters). Default: <SportId as Default>::default().

pub fn stat_types( self, value: Vec<StatType>, ) -> StatLeadersRequestBuilder<SetStatTypes<S>>
where S::StatTypes: IsUnset,

Required.

pub fn start_date( self, value: NaiveDate, ) -> StatLeadersRequestBuilder<SetStartDate<S>>
where S::StartDate: IsUnset,

Optional (Some / Option setters).

pub fn maybe_start_date( self, value: Option<NaiveDate>, ) -> StatLeadersRequestBuilder<SetStartDate<S>>
where S::StartDate: IsUnset,

Optional (Some / Option setters).

pub fn end_date( self, value: NaiveDate, ) -> StatLeadersRequestBuilder<SetEndDate<S>>
where S::EndDate: IsUnset,

Optional (Some / Option setters).

pub fn maybe_end_date( self, value: Option<NaiveDate>, ) -> StatLeadersRequestBuilder<SetEndDate<S>>
where S::EndDate: IsUnset,

Optional (Some / Option setters).

pub fn pool(self, value: PlayerPool) -> StatLeadersRequestBuilder<SetPool<S>>
where S::Pool: IsUnset,

Required.

pub fn days_back(self, value: u32) -> StatLeadersRequestBuilder<SetDaysBack<S>>
where S::DaysBack: IsUnset,

Optional (Some / Option setters). Number of days to go back for data (starting from yesterday)

pub fn maybe_days_back( self, value: Option<u32>, ) -> StatLeadersRequestBuilder<SetDaysBack<S>>
where S::DaysBack: IsUnset,

Optional (Some / Option setters). Number of days to go back for data (starting from yesterday)

pub fn limit(self, value: u16) -> StatLeadersRequestBuilder<SetLimit<S>>
where S::Limit: IsUnset,

Optional (Some / Option setters). Limit on how many leaders to show per stat. Default is 5.

pub fn maybe_limit( self, value: Option<u16>, ) -> StatLeadersRequestBuilder<SetLimit<S>>
where S::Limit: IsUnset,

Optional (Some / Option setters). Limit on how many leaders to show per stat. Default is 5.

pub fn offset(self, value: u16) -> StatLeadersRequestBuilder<SetOffset<S>>
where S::Offset: IsUnset,

Optional (Some / Option setters). Offset into results.

pub fn maybe_offset( self, value: Option<u16>, ) -> StatLeadersRequestBuilder<SetOffset<S>>
where S::Offset: IsUnset,

Optional (Some / Option setters). Offset into results.

pub fn game_types( self, value: Vec<GameType>, ) -> StatLeadersRequestBuilder<SetGameTypes<S>>
where S::GameTypes: IsUnset,

Optional (Some / Option setters). None represents all game types.

pub fn maybe_game_types( self, value: Option<Vec<GameType>>, ) -> StatLeadersRequestBuilder<SetGameTypes<S>>
where S::GameTypes: IsUnset,

Optional (Some / Option setters). None represents all game types.