Module team

Module team 

Endpoints related to teams; roster, history, affiliates, etc.

Modules

affiliates
Returns a Vec of Teams representing the minor league affiliates of a team.
alumni
Returns a list of alumni associated with a team; PeopleResponse.
coaches
Returns a list of coaches affiliated with the team; PeopleResponse
history
The history of a team’s ID, such as the Los Angeles Dodgers and the Brooklyn Dodgers.
leaders
Stat Leaders per stat in a team. Returns a TeamStatLeadersResponse.
personnel
Returns a list of personnel associated with a Team; PeopleResponse
roster
Returns a list of RosterPlayers on a teams roster.
stats
uniforms
Returns a list of uniform assets. No image sadly, just item names.

Macros

team_hydrations
Creates hydrations for a team

Structs

NamedOrganization
A named organization.
NamedTeam
A team with a name and id
OrganizationId
ID of a parent organization – still don’t know what this is.
Team
A detailed struct representing a baseball team.
TeamId
A u32 representing a team’s ID.
TeamName
A detailed description of a team’s name.
TeamsRequest
Returns a TeamsResponse.
TeamsRequestBuilder
Use builder syntax to set the inputs and finish with build().
TeamsResponse
A Vec of Teams

Enums

AllStarStatus
Honestly, no clue. Would love to know.

Traits

TeamHydrations