Module affiliates

Module affiliates 

Returns a Vec of Teams representing the minor league affiliates of a team.

Structs

TeamAffiliatesRequest
Returns a TeamsResponse.
TeamAffiliatesRequestBuilder
Use builder syntax to set the inputs and finish with build().