Returns a list of alumni associated with a team; PeopleResponse.
Structs
- Alumni
Request - Alumni
Request Builder - Use builder syntax to set the inputs and finish with
build().
Returns a list of alumni associated with a team; PeopleResponse.
build().