Module coaches

Module coaches 

Returns a list of coaches affiliated with the team; PeopleResponse

Structs

CoachesRequest
CoachesRequestBuilder
Use builder syntax to set the inputs and finish with build().