pub struct TeamHistoryRequest { /* private fields */ }Expand description
History of a TeamId throughout the years.
For example, the team history of the Los Angeles Dodgers would include those of the Brooklyn Dodgers.
Implementations
Sourceimpl TeamHistoryRequest
impl TeamHistoryRequest
Sourcepub fn builder() -> TeamHistoryRequestBuilder
pub fn builder() -> TeamHistoryRequestBuilder
Create an instance of TeamHistoryRequest using the builder syntax