Module uniforms

Module uniforms 

Returns a list of uniform assets. No image sadly, just item names.

Structs

TeamUniformAssets
A Vec of a team’s UniformAssets
UniformAsset
A uniform asset, like a Blue Jays Canada Day Hat.
UniformAssetCategory
Category; Hat, Shirt, etc.
UniformAssetCategoryId
UniformAssetId
UniformsRequest
Returns a UniformsResponse
UniformsRequestBuilder
Use builder syntax to set the inputs and finish with build().
UniformsResponse
A Vec of TeamUniformAssetss