Module transactions

Module transactions 

Structs

TransactionCommon
TransactionDates
TransactionId
TransactionsRequest
Sends a request to get the relevant transactions for a player.
TransactionsRequestBuilder
Use builder syntax to set the inputs and finish with build().
TransactionsResponse

Enums

Transaction
TransactionsRequestKind