Module attendance

Module attendance 

Structs

AttendanceRecord
AttendanceRequest
AttendanceRequestBuilder
Use builder syntax to set the inputs and finish with build().
AttendanceResponse
Within regards to attendance, the term frequently used is “Opening” over “Game”; this is for reasons including but not limited to: single ticket double headers, and rescheduled games.
DatedAttendance
SeasonWithMinorId