A conference, like in NCAA Baseball.
At the time of writing, the only two registered are the PCL American Conference and the PCL Pacific Conference.
Structs
- Conference
- A conference containing all details registered
- Conference
Id - A
u32representing the ID of the conference, used inConferencesRequest - Conferences
Request - Returns a
ConferencesResponse - Conferences
Request Builder - Use builder syntax to set the inputs and finish with
build(). - Conferences
Response - Returns a
VecofConferences - Named
Conference - Conference with a name