Module draft

Module draft 

Structs

DraftPick
DraftProspectsRequest
This request gives a list of prospects.
DraftProspectsRequestBuilder
Use builder syntax to set the inputs and finish with build().
DraftProspectsResponse
DraftRequest
This request sorts into rounds
DraftRequestBuilder
Use builder syntax to set the inputs and finish with build().
DraftRequestLatest
DraftRequestLatestBuilder
Use builder syntax to set the inputs and finish with build().
DraftResponse
DraftRound
DraftYear
EBISPersonId
School

Enums

DraftType

Functions

get_default_headshot