The thing you’re most likely here for.
This module itself acts like [crate::types] but for misc game-specific types as there are many.
Structs
- Action
Play Details - Applicable
Play Matchup Splits - Batter, Pitcher, and Men-On-Base splits; unknown type.
- AtBat
Count - The balls and strikes in a given at bat. Along with the number of outs (this technically can change during the AB due to pickoffs etc)
- Batting
Order Index - A position in the batting order, 1st, 2nd, 3rd, 4th, etc.
- Boxscore
- See [
self] - Boxscore
Request - Boxscore
Request Builder - Use builder syntax to set the inputs and finish with
build(). - Boxscore
Stat Collection - Hitting, Pitching, and Fielding stats.
- Completed
Play Details - Information supplied to
PlayDetailswhen the play is complete - Decisions
- Decisions of winner & loser (and potentially the save)
- Game
Date Time - Date & Time of the game. Note that the time is typically rounded to the hour and the :07, :05 on the hour is for the first pitch, which is a different timestamp.
- GameId
- A
u32representing a baseball game. Sport-independent - Game
Info - Misc
- Game
Pace - Game
Stat Leaders - Game records in stats like exit velocity, hit distance, etc.
- Game
Tags - Tags about a game, such as a perfect game in progress, no-hitter, etc.
- Game
Timestamps Request - Game
Timestamps Request Builder - Use builder syntax to set the inputs and finish with
build(). - HitData
- Data regarding batted-balls
- Inning
- Labelled
Value - Unparsed miscellaneous data.
- League
Game Pace - League
Game Pace Request - League
Game Pace Request Builder - Use builder syntax to set the inputs and finish with
build(). - League
Game Pace Response - Linescore
- An inning by inning record of the game’s scoring.
- Linescore
Defense - Current defense in the linescore, note that it also contains their offense too.
- Linescore
Inning Record - A record of
RHEfrom both teams in a single inning. - Linescore
Offense - Current offense in the linescore
- Linescore
Request - Returns a
Linescore - Linescore
Request Builder - Use builder syntax to set the inputs and finish with
build(). - Live
Feed Data - General information about the game
- Live
Feed Data Meta - More specific information about the “game”, child of
LiveFeedData - Live
Feed Live Data - Live data about the game – i.e. stuff that changes as the game goes on.
- Live
Feed Metadata - Metadata about the game, often not useful.
- Live
Feed Request - Returns a
LiveFeedResponse - Live
Feed Request Builder - Use builder syntax to set the inputs and finish with
build(). - Live
Feed Response - See [
self] - NoPitch
Play Details - Official
- Pickoff
Play Details - Pitch
Data - Statistical data regarding a pitch.
- Pitch
Play Details - Play
- The play(s) within an “At-Bat”
- Play
About - Miscallaneous data regarding a play
- Play
ByPlay Request - Play
ByPlay Request Builder - Use builder syntax to set the inputs and finish with
build(). - Play
Details - The result of a play, such as a Strikeout, Home Run, etc.
- Play
Event Common - Play
Matchup - Hitter & Pitcher matchup information
- Play
Stream - Meant for active & live games, gives a streamable version of the plays in a game.
- Player
Game Status Flags - Various flags about the player in the current game
- Player
With Game Data - A person with some potentially useful information regarding their performance in the current game.
- Plays
- A collection of plays, often a whole game’s worth.
- RHE
- The classic “R | H | E” and LOB in a scoreboard.
- Review
Data - Data regarding replay reviews; present on
Play, notPlayEvent. - Runner
Credit - Fielder credits to outs
- Runner
Data - Data regarding a baserunner.
- Runner
Details - Details about the runner’s movement
- Runner
Movement - Data regarding the basepath of a runner
- Sectioned
Labelled Values - Simplified
Timestamp - Represents a UTC datetime in a very simple format, ex:
20251231_235959 - Sport
Game Pace - Sport
Game Pace Request - Sport
Game Pace Request Builder - Use builder syntax to set the inputs and finish with
build(). - Sport
Game Pace Response - Statcast
HitData - Statcast data regarding batted balls, only sometimes present.
- Stepoff
Play Details - Team
Game Pace - Team
Game Pace Request - Team
Game Pace Request Builder - Use builder syntax to set the inputs and finish with
build(). - Team
Game Pace Response - Team
Review Data - Review usage for each team and if the game supports challenges.
- Team
With Game Data - A team with some potentially useful information regarding their performance in the current game.
- TopPerformer
- One of three “top performers” of the game, measured by game score.
- Weather
Conditions - General weather conditions, temperature, wind, etc.
Enums
- Base
- Contact
Hardness - Credit
Kind - Statistical credits to fielders; putouts, assists, etc.
- Double
Header Kind - Double-header information.
- Inning
Half - Half of the inning.
- Movement
Reason - Reasons for baserunner movement
- Official
Type - Play
Event - An “indivisible” play, such as pickoff, pitch, stolen base, etc.
- Play
Stream Event - An event in a game, such as the game starting, ending, a
Play(At-Bat) starting, or aPlayEventoccuring, or a challenge on a play or play event.
Functions
- deserialize_
review_ data - Errors