pub enum MovementReason {
Show 28 variants
AdvancementUnforced,
AdancementForced,
AdvancementThrow,
DoubledOff,
ThrownOut,
CalledOutReturning,
ForceOut,
RunnerCalledOut,
DefensiveIndifference,
Rundown,
OutStretching,
StolenBase2B,
StolenBase3B,
StolenBaseHome,
CaughtStealing2B,
CaughtStealing3B,
CaughtStealingHome,
Pickoff1B,
Pickoff2B,
Pickoff3B,
PickoffError1B,
PickoffError2B,
PickoffError3B,
PickoffCaughtStealing2B,
PickoffCaughtStealing3B,
PickoffCaughtStealingHome,
Interference,
HitByBall,
}Expand description
Reasons for baserunner movement
Variants
AdvancementUnforced
AdancementForced
Forced base advancement, such as moving up one base on a single.
AdvancementThrow
Advancement from a choice in throwing, such as throwing home and allowing this runner to move up a base instead.
DoubledOff
Runner fails to tag up and is forced out.
ThrownOut
CalledOutReturning
ForceOut
Standard force-out.
RunnerCalledOut
Deviation from the basepath, etc.
DefensiveIndifference
A Stolen Base with no throw.
Rundown
OutStretching
Stretching a single into a double.
StolenBase2B
StolenBase3B
StolenBaseHome
CaughtStealing2B
CaughtStealing3B
CaughtStealingHome
Pickoff1B
Successful pickoff
Pickoff2B
Successful pickoff
Pickoff3B
Successful pickoff
PickoffError1B
PickoffError2B
PickoffError3B
PickoffCaughtStealing2B
PickoffCaughtStealing3B
PickoffCaughtStealingHome
Interference
General interference
HitByBall
Implementations
Sourceimpl MovementReason
impl MovementReason
Sourcepub const fn is_pickoff(self) -> bool
pub const fn is_pickoff(self) -> bool
If the movement reason is a pickoff
Sourcepub const fn is_stolen_base_attempt(self) -> bool
pub const fn is_stolen_base_attempt(self) -> bool
If the movement reason is a stolen base attempt
Sourcepub const fn is_stolen_base(self) -> bool
pub const fn is_stolen_base(self) -> bool
If the movement reason is a stolen base