pub struct GameDateTime { /* private fields */ }Expand description
Date & Time of the game. Note that the time is typically rounded to the hour and the :07, :05 on the hour is for the first pitch, which is a different timestamp.