pub struct PlayAbout {
pub at_bat_idx: usize,
pub inning_half: InningHalf,
pub inning: Inning,
pub start_timestamp: NaiveDateTime,
pub end_timestamp: NaiveDateTime,
pub is_complete: bool,
pub is_scoring_play: Option<bool>,
pub has_review: bool,
pub has_out: bool,
pub captivating_index: usize,
/* private fields */
}Expand description
Miscallaneous data regarding a play
Fields
at_bat_idx: usizeOrdinal at bat of the game (starts at 0)
inning_half: InningHalfThe inning half this play is in
inning: InningThe inning this play is in
start_timestamp: NaiveDateTimeThe timestamp that this play begins; includes milliseconds
end_timestamp: NaiveDateTimeThe timestamp that this play ends at; includes milliseconds
is_complete: boolWhether the play is “complete” or not, i.e. opposite of ongoing.
Once a play is complete it cannot be edited
is_scoring_play: Option<bool>Whether the play itself is scoring, such as a Home Run.
Note that Plays that include PlayEvents that score runs that are not part of the Play (such as stealing home) do not indicate this as true.
This is the predicate for Plays::scoring_plays
has_review: boolWhether the play has a replay review occur. Note that At-Bats can have multiple challenges occur.
has_out: boolWhether the play has counted towards an out so far.
todo: check if includes play events like pickoffs.
captivating_index: usizeOrdinal ranking for +/- WPA effect.
1 means largest effect on WPA,
2 means second most, etc.