PlayStream

Struct PlayStream 

pub struct PlayStream { /* private fields */ }
Meant for active & live games, gives a streamable version of the plays in a game.

The PlayStream is meant to be for consistently polling the MLB API for live play-by-play updates. The list of events can be seen on PlayStreamEvent

Examples

PlayStream::new(/* game id */).run(|event: PlayStreamEvent, meta: &LiveFeedMetadata, data: &LiveFeedData| {
    match event {
        PlayStreamEvent::GameStart => println!("Game Start"),
        PlayStreamEvent::StartPlay(play) => println!("{} vs. {}", play.matchup.batter.full_name, play.matchup.pitcher.full_name),
        PlayStreamEvent::PlayEvent(play_event) => {
            match play_event {
                PlayEvent::Action { details, .. } => println!("{}", details.description),
                PlayEvent::Pitch { details, common, .. } => println!("{} -> {}", details.call, common.count),
                PlayEvent::Stepoff { .. } => println!("Stepoff"),
                PlayEvent::NoPitch { .. } => println!("No Pitch"),
                PlayEvent::Pickoff { .. } => println!("Pickoff"),
            }
        },
        PlayStreamEvent::PlayEventReviewStart(review) => println!("PlayEventReviewStart; {}", review.review_type),
        PlayStreamEvent::PlayEventReviewEnd(review) => println!("PlayEventReviewEnd; {}", review.review_type),
        PlayStreamEvent::PlayReviewStart(review) => println!("PlayReviewStart; {}", review.review_type),
        PlayStreamEvent::PlayReviewEnd(review) => println!("PlayReviewEnd; {}", review.review_type),
        PlayStreamEvent::EndPlay(play) => println!("{}", play.result.completed_play_details.as_ref().expect("Completed play").description),
        PlayStreamEvent::GameEnd(_, _, _, _) => println!("GameEnd"),
    }
}).await?;

Implementations

Source

impl PlayStream

pub fn new(game_id: impl Into<GameId>) -> Self

Source

impl PlayStream

pub async fn run<F: FnMut(PlayStreamEvent<'_>, &LiveFeedMetadata, &LiveFeedData) -> Result<ControlFlow<()>, Error>>( self, f: F, ) -> Result<(), Error>

Runs through plays until the game is over.

Errors

See request::Error

pub async fn run_custom_error<E: From<Error>, F: FnMut(PlayStreamEvent<'_>, &LiveFeedMetadata, &LiveFeedData) -> Result<ControlFlow<()>, E>>( self, f: F, ) -> Result<(), E>

Variant of the run function that allows for custom error types.

Errors

See request::Error