An abstraction over endpoints that contain fixed data, such as GameTypes, JobTypes, etc.
For types in which quick accessibility is important (and there are not tons of variants), they will be represented as an enum (GameType).
For types which have many variants and ones that would be constantly updating, they are represented as Vec<struct>s (SituationCode).
These types implement MetaKind and Requestable for ease of use.
Some of these types will have id-only variants in most responses, in which you can request details using Requestable; Position.
Structs
- Baseball
Stat - A Baseball Stat;
"hits","strikeOuts","xWoba", etc. - Baseball
Stat Id - A
StringID for aBaseballStat - Game
Status - Game
Status Id - A
Stringrepresenting theGameStatus - JobType
- Different types of baseball jobs; Umpires, Coaches, etc.
- JobType
Id - A
Stringrepresenting aJobType. - Language
- Language
Id - A
u32representing aLanguage - League
Leader Type Id - A
Stringrepresenting astata player can lead the league in. - Logical
Event Id - A
Stringrepresenting a Game Logic Event, like a count change, new batter, game status change, etc. - Meta
Request - Returns
MetaResponse<T>. - Meta
Response - Generalized response for the meta endpoints.
- Metric
- A measurement thing; typically EV, LA, pitch velocity, spin rate, etc.
- Metric
Id - A
u32representing aMetric - Named
Metric - A
Metricwith a name - Named
Position - A
Positionwith a name. - Pitch
Code - A detailed
structrepresenting everything logic-related that happened with a pitch. - Pitch
Code Id - A
Stringrepresenting a pitch, such as “F” for Foul, “S” for Swinging Strike, etc. - Pitch
Type - A detailed
structdescribing a pitch type. - Pitch
Type Id - A
Stringrepresenting pitch types,"FF"for Four-Seam Fastball,"CU"for Curveball, etc. - Platform
- A detailed
structrepresenting a Platform - Platform
Id - A
Stringrepresenting an electronic platform - Position
- A Position with every piece of data you could describe about it.
- Position
Code - A
Stringrepresenting a position on the field, such as Pitcher, 1st Baseman, etc. These values use 1-9, so Pitcher = “1”, etc. - Review
Reason - A detailed
structrepresenting a reviewable play. - Review
Reason Id - A review on a play (These codes often are just single letters and mean nothing and only useful for lookup purposes.)
- Schedule
Event Type - A detailed
structrepresenting an event in the schedule. - Schedule
Event Type Id - A
Stringcode representing aScheduleEventType - Situation
Code - A specific situation in a game
- Situation
Code Id - A
Stringrepresenting a situation, such as c00 for a 0-0 count - SkyDescription
- A detailed
structrepresenting the sky conditions - SkyDescription
Id - A
Stringdescribing the conditions of the sky - Stat
Type - A
Stringrepresenting a specific type of stat collection - Wind
Direction - A detailed
structrepresenting the direction wind is going. - Wind
Direction Id - A
Stringrepresenting a direction the wind is going
Enums
- Abstract
Game Code - Basic game status code, describes whether the game is in the past (finished), present (underway), or future (scheduled).
- Coded
Game State - Detailed game status (use
AbstractGameCodefor simpler responses) - DayNight
- Whether the sky shows daytime or nighttime
- Event
Type - Event
Type From StrError - Game
Type - HitTrajectory
- Different coarse definitions of how a ball is hit – likely up to scorers interpretation.
- Roster
Type - Types of roster definitions
- Situation
Code Category - Situation
Code Filter - Filters searching through situation codes to filter with multiple situation codes.
- Standings
Type - Different types of standings
- Stat
Group - Hitting, Pitching, etc.
- Unit
- A unit of measurement
Traits
- Meta
Kind - Represents a type that is metadata.