StandingsType

Enum StandingsType 

pub enum StandingsType {
Show 13 variants RegularSeason, WildCard, DivisionLeaders, WildCardWithLeaders, FirstHalf, SecondHalf, SpringTraining, Postseason, ByDivision, ByConference, ByLeague, ByOrganization, CurrentHalf,
}
Different types of standings

Variants



RegularSeason

Regular Season Standings



WildCard

Wild card standings



DivisionLeaders

Division Leader standings



WildCardWithLeaders

Wild card standings with Division Leaders



FirstHalf

First half standings. Only valid for leagues with a split season.



SecondHalf

Second half standings. Only valid for leagues with a split season.



SpringTraining

Spring Training Standings



Postseason

Postseason Standings



ByDivision

Standings by Division



ByConference

Standings by Conference



ByLeague

Standings by League



ByOrganization

Standing by Organization



CurrentHalf

Current Half Standings. Returns standings in the current half for split season leagues and overall standings for full season leagues.