A description of a person in baseball.
Person works through multi-level definition.
PersonId, which deserializes a:
"person": {
"id": 660271,
"link": "/api/v1/people/660271"
}NamedPerson, which deserializes a:
"person": {
"id": 660271,
"link": "/api/v1/people/660271",
"fullName": "Shohei Ohtani"
}Person, which deserializes a lot of extra fields, see http://statsapi.mlb.com/api/v1/people/660271. Technically,Personis actually an enum which separates fields supplied forBallplayers (handedness, draft year, etc.), and fields available to people like coaches and umpires (such as last name, age, etc.)RegularPerson.
This module also contains person_hydrations, which are used to get additional data about people when making requests.
Modules
- free_
agents - Lists the registered free agents at the time.
- players
- Lists all players in the sport in a given season.
- stats
- Gets the stats of a player for a single game.
Macros
- person_
hydrations - Creates hydrations for a person
Structs
- Ballplayer
- A baseball player.
- Birth
Data - Data regarding birthplace.
- Body
Measurements - Height and weight
- Education
- Schools the ballplayer went to.
- Jersey
Number - The number on the back of a jersey, useful for radix sorts maybe??
- Named
Person - A person with a name.
- People
Response - Response containing a list of people
- Person
Id - A
u32that represents a person. - Person
Request - Returns a
PeopleResponse. - Person
Request Builder - Use builder syntax to set the inputs and finish with
build(). - Preferred
Team Data - Data regarding preferred team, likely for showcasing the player with a certain look regardless of the time.
- Regular
Person - A regular person; detailed-name stuff.
- Relative
- Relative to the ballplayer, father, son, etc.
- Strike
Zone Measurements - Strike zone dimensions, measured in feet from the ground.
Enums
- Person
- A complete person response for a hydrated request. Ballplayers have more fields.
Traits
- Person
Hydrations - A type that is made with
person_hydrations!