Module stats

Module stats 

Gets the stats of a player for a single game.

Structs

PersonSingleGameStatsRequest
PersonSingleGameStatsRequestBuilder
Use builder syntax to set the inputs and finish with build().
PersonSingleGameStatsResponse
SingleGameStats
SingleGameStatsRequestData
SingleGameStatsRequestDataBuilder
Use builder syntax to set the inputs and finish with build().
SingleGameStatsSimplifiedGameLogSplit
SingleGameStatsSimplifiedPlayLogSplit
SingleGameStatsVsPlayer5YSplit