pub struct TeamWithStandings {
pub team: NamedTeam,
pub standings: Standings,
pub score: Option<TeamWithStandingsGameScore>,
pub is_split_squad_game: bool,
pub series_ordinal: Option<u32>,
}Fields
team: NamedTeamstandings: Standingsscore: Option<TeamWithStandingsGameScore>is_split_squad_game: boolseries_ordinal: Option<u32>Refers to the ordinal of series, not within the current series.
Starts at 1.
None if the current game is not of a series-format (ex: Spring Training)