pub struct TeamRecord<H: StandingsHydrations> {Show 23 fields
pub team: H::Team,
pub season: SeasonId,
pub games_played: usize,
pub runs_allowed: usize,
pub runs_scored: usize,
pub is_divisional_champion: bool,
pub is_divisional_leader: bool,
pub has_wildcard: bool,
pub last_updated: NaiveDateTime,
pub streak: Streak,
pub splits: RecordSplits,
pub clinch_kind: ClinchKind,
pub games_back: GamesBack,
pub wild_card_games_back: GamesBack,
pub league_games_back: GamesBack,
pub spring_training_games_back: GamesBack,
pub sport_games_back: GamesBack,
pub division_games_back: GamesBack,
pub conference_games_back: GamesBack,
pub record: Record,
pub divisional_rank: Option<usize>,
pub league_rank: Option<usize>,
pub sport_rank: Option<usize>,
}Expand description
Main bulk of the response; the team’s record and standings information. Lots of stuff here.
Fields
team: H::Teamseason: SeasonIdgames_played: usizeruns_allowed: usizeruns_scored: usizeis_divisional_champion: boolis_divisional_leader: boolhas_wildcard: boollast_updated: NaiveDateTimestreak: Streaksplits: RecordSplitsclinch_kind: ClinchKindgames_back: GamesBackwild_card_games_back: GamesBackleague_games_back: GamesBackspring_training_games_back: GamesBacksport_games_back: GamesBackdivision_games_back: GamesBackconference_games_back: GamesBackrecord: Recorddivisional_rank: Option<usize>league_rank: Option<usize>sport_rank: Option<usize>Implementations
Sourceimpl<H: StandingsHydrations> TeamRecord<H>
impl<H: StandingsHydrations> TeamRecord<H>
Sourcepub fn expected_win_loss_pct(&self) -> ThreeDecimalPlaceRateStat
pub fn expected_win_loss_pct(&self) -> ThreeDecimalPlaceRateStat
Uses the pythagorean expected win loss pct formula
Sourcepub fn expected_end_of_season_record(&self) -> Record
pub fn expected_end_of_season_record(&self) -> Record
Assumes 162 total games. Recommended to use the other function if available
Sourcepub fn expected_end_of_season_record_with_total_games(
&self,
total_games: usize,
) -> Record
pub fn expected_end_of_season_record_with_total_games( &self, total_games: usize, ) -> Record
Expected record at the end of the season considering the games already played and the expected win loss pct.
Sourcepub fn run_differential(&self) -> isize
pub fn run_differential(&self) -> isize
Net runs scored for the team