Module stats

Module stats 

Modules

leaders
macros
parse
raw
units
wrappers

Structs

PlayStat

Traits

RawStat
Represents the types defined in raw, not the wrapped final types. In the serialized format, this represents the `stat’ field.
SingletonSplitStat
Represents types that are made from a single ‘split’ in the serialized format (able to be deserialized)
Stat
StatTypeStats
Stats

Type Aliases

PitchStat