Endpoints related to teams; roster, history, affiliates, etc.
Modules
- affiliates
- Returns a
VecofTeams representing the minor league affiliates of a team. - alumni
- Returns a list of alumni associated with a team;
PeopleResponse. - coaches
- Returns a list of coaches affiliated with the team;
PeopleResponse - history
- The history of a team’s ID, such as the Los Angeles Dodgers and the Brooklyn Dodgers.
- leaders
- Stat Leaders per stat in a team. Returns a
TeamStatLeadersResponse. - personnel
- Returns a list of personnel associated with a
Team;PeopleResponse - roster
- Returns a list of
RosterPlayers on a teams roster. - stats
- uniforms
- Returns a list of uniform assets. No image sadly, just item names.
Macros
- team_
hydrations - Creates hydrations for a team
Structs
- Named
Organization - A named organization.
- Named
Team - A team with a name and id
- Organization
Id - ID of a parent organization – still don’t know what this is.
- Team
- A detailed
structrepresenting a baseball team. - TeamId
- A
u32representing a team’s ID. - Team
Name - A detailed description of a team’s name.
- Teams
Request - Returns a
TeamsResponse. - Teams
Request Builder - Use builder syntax to set the inputs and finish with
build(). - Teams
Response - A
VecofTeams
Enums
- AllStar
Status - Honestly, no clue. Would love to know.