Returns a list of coaches affiliated with the team; PeopleResponse
Structs
- Coaches
Request - Coaches
Request Builder - Use builder syntax to set the inputs and finish with
build().
Returns a list of coaches affiliated with the team; PeopleResponse
build().